#!/usr/bin/env python
# -*- coding: utf-8 -*-
# **********************************************************************************************************************
# File: constants.py
# Project: MOOSE Version 0.1.0
# Created: 22.03.2022
# Author: Lalith Kumar Shiyam Sundar
# Email: lalith.shiyamsundar@meduniwien.ac.at
# Institute: Quantitative Imaging and Medical Physics, Medical University of Vienna
# Description: This module contains all the constants that are being used in the MOOSE project.
# License: Apache 2.0
# **********************************************************************************************************************
# Hard-coded variables
import os

NORMDB_DIR = os.getenv('SIM_SPACE_DIR')
BRAIN_DETECTOR_MODEL = os.getenv('BRAIN_DETECTOR_DIR')
CROPPED_BRAIN_FROM_PET = "cropped-brain-from-PET_0000.nii.gz"
CROPPED_PADDING = 15  # in mm
CROPPED_SPINE_FROM_CT = "cropped-spine-from-ct_0000.nii.gz"
NUM_OF_ORGANS = 12
NUM_OF_BONES = 20
NUM_OF_FAT_MUSCLE = 3
NUM_OF_PSOAS = 1
NUM_OF_BRAIN = 83
DUAL_ORGANS = [
    "Adrenal-glands",
    "Kidneys",
    "Lung",
    "Carpal",
    "Clavicle",
    "Femur",
    "Fibula",
    "Humerus",
    "Metacarpal",
    "Metatarsal",
    "Patella",
    "Fingers",
    "Radius",
    "Scapula",
    "Tarsal",
    "Tibia",
    "Toes",
    "Ulna",
    "Psoas",
]

ORGAN_INDEX = {
    1: 'Adrenal-glands',
    2: 'Aorta',
    3: 'Bladder',
    4: 'Brain',
    5: 'Heart',
    6: 'Kidneys',
    7: 'Liver',
    8: 'Pancreas',
    9: 'Spleen',
    10: 'Thyroid',
    11: 'Inferior-vena-cava',
    12: 'Lung',
    13: 'Carpal',
    14: 'Clavicle',
    15: 'Femur',
    16: 'Fibula',
    17: 'Humerus',
    18: 'Metacarpal',
    19: 'Metatarsal',
    20: 'Patella',
    21: 'Pelvis',
    22: 'Phalanges-of-the-hand',
    23: 'Radius',
    24: 'Ribcage',
    25: 'Scapula',
    26: 'Skull',
    27: 'Spine',
    28: 'Sternum',
    29: 'Tarsal',
    30: 'Tibia',
    31: 'Phalanges-of-the-feet',
    32: 'Ulna',
    33: 'Skeletal-muscle',
    34: 'Subcutaneous-fat',
    35: 'Torso-fat',
    36: 'Psoas',
    37: 'R-Hippocampus',
    38: 'L-Hippocampus',
    39: 'R-Amygdala',
    40: 'L-Amygdala',
    41: 'R-Anterior-temporal-lobe-medial-part',
    42: 'L-Anterior-temporal-lobe-medial-part',
    43: 'R-Anterior-temporal-lobe-lateral-part',
    44: 'L-Anterior-temporal-lobe-lateral-part',
    45: 'R-Parahippocampal-and-ambient-gyri',
    46: 'L-Parahippocampal-and-ambient-gyri',
    47: 'R-Superior-temporal-gyrus-posterior-part',
    48: 'L-Superior-temporal-gyrus-posterior-part',
    49: 'R-Middle-and-inferior-temporal-gyrus',
    50: 'L-Middle-and-inferior-temporal-gyrus',
    51: 'R-Fusiform-gyrus',
    52: 'L-Fusiform-gyrus',
    53: 'R-Cerebellum',
    54: 'L-Cerebellum',
    55: 'Brainstem',
    56: 'L-Insula',
    57: 'R-Insula',
    58: 'L-Lateral-remainder-of-occipital-lobe',
    59: 'R-Lateral-remainder-of-occipital-lobe',
    60: 'L-Cingulate-gyrus-gyrus-cinguli-anterior-part',
    61: 'R-Cingulate-gyrus-gyrus-cinguli-anterior-part',
    62: 'L-Cingulate-gyrus-gyrus-cinguli-posterior-part',
    63: 'R-Cingulate-gyrus-gyrus-cinguli-posterior-part',
    64: 'L-Middle-frontal-gyrus',
    65: 'R-Middle-frontal-gyrus',
    66: 'L-Posterior-temporal-lobe',
    67: 'R-Posterior-temporal-lobe',
    68: 'L-Inferiolateral-remainder-of-parietal-lobe',
    69: 'R-Inferiolateral-remainder-of-parietal-lobe',
    70: 'L-Caudate-nucleus',
    71: 'R-Caudate-nucleus',
    72: 'L-Nucleus-accumbens',
    73: 'R-Nucleus-accumbens',
    74: 'L-Putamen',
    75: 'R-Putamen',
    76: 'L-Thalamus',
    77: 'R-Thalamus',
    78: 'L-Pallidum',
    79: 'R-Pallidum',
    80: 'Corpus-callosum',
    81: 'R-Lateral-ventricle-excluding-temporal-horn',
    82: 'L-Lateral-ventricle-excluding-temporal-horn',
    83: 'R-Lateral-ventricle-temporal-horn',
    84: 'L-Lateral-ventricle-temporal-horn',
    85: 'Third-ventricle',
    86: 'L-Precentral-gyrus',
    87: 'R-Precentral-gyrus',
    88: 'L-Straight-gyrus',
    89: 'R-Straight-gyrus',
    90: 'L-Anterior-orbital-gyrus',
    91: 'R-Anterior-orbital-gyrus',
    92: 'L-Inferior-frontal-gyrus',
    93: 'R-Inferior-frontal-gyrus',
    94: 'L-Superior-frontal-gyrus',
    95: 'R-Superior-frontal-gyrus',
    96: 'L-Postcentral-gyrus',
    97: 'R-Postcentral-gyrus',
    98: 'L-Superior-parietal-gyrus',
    99: 'R-Superior-parietal-gyrus',
    100: 'L-Lingual-gyrus',
    101: 'R-Lingual-gyrus',
    102: 'L-Cuneus',
    103: 'R-Cuneus',
    104: 'L-Medial-orbital-gyrus',
    105: 'R-Medial-orbital-gyrus',
    106: 'L-Lateral-orbital-gyrus',
    107: 'R-Lateral-orbital-gyrus',
    108: 'L-Posterior-orbital-gyrus',
    109: 'R-Posterior-orbital-gyrus',
    110: 'L-Substantia-nigra',
    111: 'R-Substantia-nigra',
    112: 'L-Subgenual-frontal-cortex',
    113: 'R-Subgenual-frontal-cortex',
    114: 'L-Subcallosal-area',
    115: 'R-Subcallosal-area',
    116: 'L-Pre-subgenual-frontal-cortex',
    117: 'R-Pre-subgenual-frontal-cortex',
    118: 'L-Superior-temporal-gyrus-anterior-part',
    119: 'R-Superior-temporal-gyrus-anterior-part'
}

ORGAN_INDEX_SPLIT = {
    1: 'R-Adrenal-glands',
    2: 'L-Adrenal-glands',
    3: 'Aorta',
    4: 'Brain',
    5: 'Bladder',
    6: 'Heart',
    7: 'R-Kidneys',
    8: 'L-Kidneys',
    9: 'Liver',
    10: 'Pancreas',
    11: 'Spleen',
    12: 'Thyroid',
    13: 'Inferior-vena-cava',
    14: 'R-Lung',
    15: 'L-Lung',
    16: 'R-Carpal',
    17: 'L-Carpal',
    18: 'R-Clavicle',
    19: 'L-Clavicle',
    20: 'R-Femur',
    21: 'L-Femur',
    22: 'R-Fibula',
    23: 'L-Fibula',
    24: 'R-Humerus',
    25: 'L-Humerus',
    26: 'R-Metacarpal',
    27: 'L-Metacarpal',
    28: 'R-Metatarsal',
    29: 'L-Metatarsal',
    30: 'R-Patella',
    31: 'L-Patella',
    32: 'Pelvis',
    33: 'R-Fingers',
    34: 'L-Fingers',
    35: 'R-Radius',
    36: 'L-Radius',
    37: 'Ribcage',
    38: 'R-Scapula',
    39: 'L-Scapula',
    40: 'Skull',
    41: 'Spine',
    42: 'Sternum',
    43: 'R-Tarsal',
    44: 'L-Tarsal',
    45: 'R-Tibia',
    46: 'L-Tibia',
    47: 'R-Toes',
    48: 'L-Toes',
    49: 'R-Ulna',
    50: 'L-Ulna',
    51: 'Skeletal-muscle',
    52: 'Subcutaneous-fat',
    53: 'Torso-fat',
    54: 'R-Psoas',
    55: 'L-Psoas',
    56: 'R-Hippocampus',
    57: 'L-Hippocampus',
    58: 'R-Amygdala',
    59: 'L-Amygdala',
    60: 'R-Anterior-temporal-lobe-medial-part',
    61: 'L-Anterior-temporal-lobe-medial-part',
    62: 'R-Anterior-temporal-lobe-lateral-part',
    63: 'L-Anterior-temporal-lobe-lateral-part',
    64: 'R-Parahippocampal-and-ambient-gyri',
    65: 'L-Parahippocampal-and-ambient-gyri',
    66: 'R-Superior-temporal-gyrus-posterior-part',
    67: 'L-Superior-temporal-gyrus-posterior-part',
    68: 'R-Middle-and-inferior-temporal-gyrus',
    69: 'L-Middle-and-inferior-temporal-gyrus',
    70: 'R-Fusiform-gyrus',
    71: 'L-Fusiform-gyrus',
    72: 'R-Cerebellum',
    73: 'L-Cerebellum',
    74: 'Brainstem',
    75: 'L-Insula',
    76: 'R-Insula',
    77: 'L-Lateral-remainder-of-occipital-lobe',
    78: 'R-Lateral-remainder-of-occipital-lobe',
    79: 'L-Cingulate-gyrus-gyrus-cinguli-anterior-part',
    80: 'R-Cingulate-gyrus-gyrus-cinguli-anterior-part',
    81: 'L-Cingulate-gyrus-gyrus-cinguli-posterior-part',
    82: 'R-Cingulate-gyrus-gyrus-cinguli-posterior-part',
    83: 'L-Middle-frontal-gyrus',
    84: 'R-Middle-frontal-gyrus',
    85: 'L-Posterior-temporal-lobe',
    86: 'R-Posterior-temporal-lobe',
    87: 'L-Inferiolateral-remainder-of-parietal-lobe',
    88: 'R-Inferiolateral-remainder-of-parietal-lobe',
    89: 'L-Caudate-nucleus',
    90: 'R-Caudate-nucleus',
    91: 'L-Nucleus-accumbens',
    92: 'R-Nucleus-accumbens',
    93: 'L-Putamen',
    94: 'R-Putamen',
    95: 'L-Thalamus',
    96: 'R-Thalamus',
    97: 'L-Pallidum',
    98: 'R-Pallidum',
    99: 'Corpus-callosum',
    100: 'R-Lateral-ventricle-excluding-temporal-horn',
    101: 'L-Lateral-ventricle-excluding-temporal-horn',
    102: 'R-Lateral-ventricle-temporal-horn',
    103: 'L-Lateral-ventricle-temporal-horn',
    104: 'Third-ventricle',
    105: 'L-Precentral-gyrus',
    106: 'R-Precentral-gyrus',
    107: 'L-Straight-gyrus',
    108: 'R-Straight-gyrus',
    109: 'L-Anterior-orbital-gyrus',
    110: 'R-Anterior-orbital-gyrus',
    111: 'L-Inferior-frontal-gyrus',
    112: 'R-Inferior-frontal-gyrus',
    113: 'L-Superior-frontal-gyrus',
    114: 'R-Superior-frontal-gyrus',
    115: 'L-Postcentral-gyrus',
    116: 'R-Postcentral-gyrus',
    117: 'L-Superior-parietal-gyrus',
    118: 'R-Superior-parietal-gyrus',
    119: 'L-Lingual-gyrus',
    120: 'R-Lingual-gyrus',
    121: 'L-Cuneus',
    122: 'R-Cuneus',
    123: 'L-Medial-orbital-gyrus',
    124: 'R-Medial-orbital-gyrus',
    125: 'L-Lateral-orbital-gyrus',
    126: 'R-Lateral-orbital-gyrus',
    127: 'L-Posterior-orbital-gyrus',
    128: 'R-Posterior-orbital-gyrus',
    129: 'L-Substantia-nigra',
    130: 'R-Substantia-nigra',
    131: 'L-Subgenual-frontal-cortex',
    132: 'R-Subgenual-frontal-cortex',
    133: 'L-Subcallosal-area',
    134: 'R-Subcallosal-area',
    135: 'L-Pre-subgenual-frontal-cortex',
    136: 'R-Pre-subgenual-frontal-cortex',
    137: 'L-Superior-temporal-gyrus-anterior-part',
    138: 'R-Superior-temporal-gyrus-anterior-part'
}
